Struct Config
#[repr(transparent)]pub struct Config(pub u32);Expand description
CONFIG register.
Tuple Fields
0: u32Implementations
impl Config
impl Config
pub const fn dis_group_write(&self) -> bool
pub const fn dis_group_write(&self) -> bool
Burst write Control: - 0 : burst write allowed - 1 : burst write forbidden.
pub fn set_dis_group_write(&mut self, val: bool)
pub fn set_dis_group_write(&mut self, val: bool)
Burst write Control: - 0 : burst write allowed - 1 : burst write forbidden.
pub const fn wait_states(&self) -> u8
pub const fn wait_states(&self) -> u8
Number of wait states to be inserted on Flash read (AHB accesses).
pub fn set_wait_states(&mut self, val: u8)
pub fn set_wait_states(&mut self, val: u8)
Number of wait states to be inserted on Flash read (AHB accesses).